# Tetra

Full stack component framework for [Django](http://djangoproject.com) using [Alpine.js](https://alpinejs.dev)

The package `tetraframework` was renamed to `tetra`: 
This is just an empty transition package that depends on `tetra`.

Ressources:
* https://github.com/tetra-framework/tetra
* https://www.tetraframework.com/

For new projects, install:
```bash
python -m pip install tetra
```

If you already had `tetraframework` installed, you can just upgrade it, and remove the old package afterwords:

```bash
# upgrade tetraframework
pip install -U tetraframework
# This will install "tetra" as dependency...
 
# now it should be safe to remove the old package:
pip uninstall tetraframework
```
